/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;
import org.gnu.glib.GObject;
import org.gnu.glib.Handle;
/**
 *
 */
public class PangoAttrEmbossed extends GObject 
{
    /****************************************
     * BEGINNING OF JNI CODE
     ****************************************/
    native static final protected boolean getEmbossed (Handle obj);
    native static final protected Handle gdk_pango_attr_embossed_new (boolean embossed);
    /****************************************
     * END OF JNI CODE
     ****************************************/
}

